package models

import (
    i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e "time"
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91 "github.com/microsoft/kiota-abstractions-go/serialization"
)

// Alert provides operations to manage the admin singleton.
type Alert struct {
    Entity
    // Name or alias of the activity group (attacker) this alert is attributed to.
    activityGroupName *string
    // The alertDetections property
    alertDetections []AlertDetectionable
    // Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).
    assignedTo *string
    // Azure subscription ID, present if this alert is related to an Azure resource.
    azureSubscriptionId *string
    // Azure Active Directory tenant ID. Required.
    azureTenantId *string
    // Category of the alert (for example, credentialTheft, ransomware, etc.).
    category *string
    // Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).
    closedDateTime *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time
    // Security-related stateful information generated by the provider about the cloud application/s related to this alert.
    cloudAppStates []CloudAppSecurityStateable
    // Customer-provided comments on alert (for customer alert management) (supports update).
    comments []string
    // Confidence of the detection logic (percentage between 1-100).
    confidence *int32
    // Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
    createdDateTime *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time
    // Alert description.
    description *string
    // Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).
    detectionIds []string
    // Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
    eventDateTime *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time
    // Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)
    feedback *AlertFeedback
    // Security-related stateful information generated by the provider about the file(s) related to this alert.
    fileStates []FileSecurityStateable
    // A collection of alertHistoryStates comprising an audit log of all updates made to an alert.
    historyStates []AlertHistoryStateable
    // Security-related stateful information generated by the provider about the host(s) related to this alert.
    hostStates []HostSecurityStateable
    // IDs of incidents related to current alert.
    incidentIds []string
    // The investigationSecurityStates property
    investigationSecurityStates []InvestigationSecurityStateable
    // The lastEventDateTime property
    lastEventDateTime *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time
    // Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
    lastModifiedDateTime *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time
    // Threat Intelligence pertaining to malware related to this alert.
    malwareStates []MalwareStateable
    // The messageSecurityStates property
    messageSecurityStates []MessageSecurityStateable
    // Security-related stateful information generated by the provider about the network connection(s) related to this alert.
    networkConnections []NetworkConnectionable
    // Security-related stateful information generated by the provider about the process or processes related to this alert.
    processes []Processable
    // Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).
    recommendedActions []string
    // Security-related stateful information generated by the provider about the registry keys related to this alert.
    registryKeyStates []RegistryKeyStateable
    // Resources related to current alert. For example, for some alerts this can have the Azure Resource value.
    securityResources []SecurityResourceable
    // The severity property
    severity *AlertSeverity
    // Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.
    sourceMaterials []string
    // The status property
    status *AlertStatus
    // User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).
    tags []string
    // Alert title. Required.
    title *string
    // Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.
    triggers []AlertTriggerable
    // The uriClickSecurityStates property
    uriClickSecurityStates []UriClickSecurityStateable
    // Security-related stateful information generated by the provider about the user accounts related to this alert.
    userStates []UserSecurityStateable
    // Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.
    vendorInformation SecurityVendorInformationable
    // Threat intelligence pertaining to one or more vulnerabilities related to this alert.
    vulnerabilityStates []VulnerabilityStateable
}
// NewAlert instantiates a new alert and sets the default values.
func NewAlert()(*Alert) {
    m := &Alert{
        Entity: *NewEntity(),
    }
    odataTypeValue := "#microsoft.graph.alert";
    m.SetOdataType(&odataTypeValue);
    return m
}
// CreateAlertFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value
func CreateAlertFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error) {
    return NewAlert(), nil
}
// GetActivityGroupName gets the activityGroupName property value. Name or alias of the activity group (attacker) this alert is attributed to.
func (m *Alert) GetActivityGroupName()(*string) {
    if m == nil {
        return nil
    } else {
        return m.activityGroupName
    }
}
// GetAlertDetections gets the alertDetections property value. The alertDetections property
func (m *Alert) GetAlertDetections()([]AlertDetectionable) {
    if m == nil {
        return nil
    } else {
        return m.alertDetections
    }
}
// GetAssignedTo gets the assignedTo property value. Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).
func (m *Alert) GetAssignedTo()(*string) {
    if m == nil {
        return nil
    } else {
        return m.assignedTo
    }
}
// GetAzureSubscriptionId gets the azureSubscriptionId property value. Azure subscription ID, present if this alert is related to an Azure resource.
func (m *Alert) GetAzureSubscriptionId()(*string) {
    if m == nil {
        return nil
    } else {
        return m.azureSubscriptionId
    }
}
// GetAzureTenantId gets the azureTenantId property value. Azure Active Directory tenant ID. Required.
func (m *Alert) GetAzureTenantId()(*string) {
    if m == nil {
        return nil
    } else {
        return m.azureTenantId
    }
}
// GetCategory gets the category property value. Category of the alert (for example, credentialTheft, ransomware, etc.).
func (m *Alert) GetCategory()(*string) {
    if m == nil {
        return nil
    } else {
        return m.category
    }
}
// GetClosedDateTime gets the closedDateTime property value. Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).
func (m *Alert) GetClosedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    if m == nil {
        return nil
    } else {
        return m.closedDateTime
    }
}
// GetCloudAppStates gets the cloudAppStates property value. Security-related stateful information generated by the provider about the cloud application/s related to this alert.
func (m *Alert) GetCloudAppStates()([]CloudAppSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.cloudAppStates
    }
}
// GetComments gets the comments property value. Customer-provided comments on alert (for customer alert management) (supports update).
func (m *Alert) GetComments()([]string) {
    if m == nil {
        return nil
    } else {
        return m.comments
    }
}
// GetConfidence gets the confidence property value. Confidence of the detection logic (percentage between 1-100).
func (m *Alert) GetConfidence()(*int32) {
    if m == nil {
        return nil
    } else {
        return m.confidence
    }
}
// GetCreatedDateTime gets the createdDateTime property value. Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
func (m *Alert) GetCreatedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    if m == nil {
        return nil
    } else {
        return m.createdDateTime
    }
}
// GetDescription gets the description property value. Alert description.
func (m *Alert) GetDescription()(*string) {
    if m == nil {
        return nil
    } else {
        return m.description
    }
}
// GetDetectionIds gets the detectionIds property value. Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).
func (m *Alert) GetDetectionIds()([]string) {
    if m == nil {
        return nil
    } else {
        return m.detectionIds
    }
}
// GetEventDateTime gets the eventDateTime property value. Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
func (m *Alert) GetEventDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    if m == nil {
        return nil
    } else {
        return m.eventDateTime
    }
}
// GetFeedback gets the feedback property value. Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)
func (m *Alert) GetFeedback()(*AlertFeedback) {
    if m == nil {
        return nil
    } else {
        return m.feedback
    }
}
// GetFieldDeserializers the deserialization information for the current model
func (m *Alert) GetFieldDeserializers()(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error)) {
    res := m.Entity.GetFieldDeserializers()
    res["activityGroupName"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetActivityGroupName(val)
        }
        return nil
    }
    res["alertDetections"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateAlertDetectionFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]AlertDetectionable, len(val))
            for i, v := range val {
                res[i] = v.(AlertDetectionable)
            }
            m.SetAlertDetections(res)
        }
        return nil
    }
    res["assignedTo"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetAssignedTo(val)
        }
        return nil
    }
    res["azureSubscriptionId"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetAzureSubscriptionId(val)
        }
        return nil
    }
    res["azureTenantId"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetAzureTenantId(val)
        }
        return nil
    }
    res["category"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetCategory(val)
        }
        return nil
    }
    res["closedDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetClosedDateTime(val)
        }
        return nil
    }
    res["cloudAppStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateCloudAppSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]CloudAppSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(CloudAppSecurityStateable)
            }
            m.SetCloudAppStates(res)
        }
        return nil
    }
    res["comments"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfPrimitiveValues("string")
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]string, len(val))
            for i, v := range val {
                res[i] = *(v.(*string))
            }
            m.SetComments(res)
        }
        return nil
    }
    res["confidence"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetInt32Value()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetConfidence(val)
        }
        return nil
    }
    res["createdDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetCreatedDateTime(val)
        }
        return nil
    }
    res["description"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetDescription(val)
        }
        return nil
    }
    res["detectionIds"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfPrimitiveValues("string")
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]string, len(val))
            for i, v := range val {
                res[i] = *(v.(*string))
            }
            m.SetDetectionIds(res)
        }
        return nil
    }
    res["eventDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetEventDateTime(val)
        }
        return nil
    }
    res["feedback"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetEnumValue(ParseAlertFeedback)
        if err != nil {
            return err
        }
        if val != nil {
            m.SetFeedback(val.(*AlertFeedback))
        }
        return nil
    }
    res["fileStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateFileSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]FileSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(FileSecurityStateable)
            }
            m.SetFileStates(res)
        }
        return nil
    }
    res["historyStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateAlertHistoryStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]AlertHistoryStateable, len(val))
            for i, v := range val {
                res[i] = v.(AlertHistoryStateable)
            }
            m.SetHistoryStates(res)
        }
        return nil
    }
    res["hostStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateHostSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]HostSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(HostSecurityStateable)
            }
            m.SetHostStates(res)
        }
        return nil
    }
    res["incidentIds"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfPrimitiveValues("string")
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]string, len(val))
            for i, v := range val {
                res[i] = *(v.(*string))
            }
            m.SetIncidentIds(res)
        }
        return nil
    }
    res["investigationSecurityStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateInvestigationSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]InvestigationSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(InvestigationSecurityStateable)
            }
            m.SetInvestigationSecurityStates(res)
        }
        return nil
    }
    res["lastEventDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetLastEventDateTime(val)
        }
        return nil
    }
    res["lastModifiedDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetLastModifiedDateTime(val)
        }
        return nil
    }
    res["malwareStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateMalwareStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]MalwareStateable, len(val))
            for i, v := range val {
                res[i] = v.(MalwareStateable)
            }
            m.SetMalwareStates(res)
        }
        return nil
    }
    res["messageSecurityStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateMessageSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]MessageSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(MessageSecurityStateable)
            }
            m.SetMessageSecurityStates(res)
        }
        return nil
    }
    res["networkConnections"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateNetworkConnectionFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]NetworkConnectionable, len(val))
            for i, v := range val {
                res[i] = v.(NetworkConnectionable)
            }
            m.SetNetworkConnections(res)
        }
        return nil
    }
    res["processes"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateProcessFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]Processable, len(val))
            for i, v := range val {
                res[i] = v.(Processable)
            }
            m.SetProcesses(res)
        }
        return nil
    }
    res["recommendedActions"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfPrimitiveValues("string")
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]string, len(val))
            for i, v := range val {
                res[i] = *(v.(*string))
            }
            m.SetRecommendedActions(res)
        }
        return nil
    }
    res["registryKeyStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateRegistryKeyStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]RegistryKeyStateable, len(val))
            for i, v := range val {
                res[i] = v.(RegistryKeyStateable)
            }
            m.SetRegistryKeyStates(res)
        }
        return nil
    }
    res["securityResources"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateSecurityResourceFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]SecurityResourceable, len(val))
            for i, v := range val {
                res[i] = v.(SecurityResourceable)
            }
            m.SetSecurityResources(res)
        }
        return nil
    }
    res["severity"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetEnumValue(ParseAlertSeverity)
        if err != nil {
            return err
        }
        if val != nil {
            m.SetSeverity(val.(*AlertSeverity))
        }
        return nil
    }
    res["sourceMaterials"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfPrimitiveValues("string")
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]string, len(val))
            for i, v := range val {
                res[i] = *(v.(*string))
            }
            m.SetSourceMaterials(res)
        }
        return nil
    }
    res["status"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetEnumValue(ParseAlertStatus)
        if err != nil {
            return err
        }
        if val != nil {
            m.SetStatus(val.(*AlertStatus))
        }
        return nil
    }
    res["tags"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfPrimitiveValues("string")
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]string, len(val))
            for i, v := range val {
                res[i] = *(v.(*string))
            }
            m.SetTags(res)
        }
        return nil
    }
    res["title"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetTitle(val)
        }
        return nil
    }
    res["triggers"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateAlertTriggerFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]AlertTriggerable, len(val))
            for i, v := range val {
                res[i] = v.(AlertTriggerable)
            }
            m.SetTriggers(res)
        }
        return nil
    }
    res["uriClickSecurityStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateUriClickSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]UriClickSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(UriClickSecurityStateable)
            }
            m.SetUriClickSecurityStates(res)
        }
        return nil
    }
    res["userStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateUserSecurityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]UserSecurityStateable, len(val))
            for i, v := range val {
                res[i] = v.(UserSecurityStateable)
            }
            m.SetUserStates(res)
        }
        return nil
    }
    res["vendorInformation"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetObjectValue(CreateSecurityVendorInformationFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            m.SetVendorInformation(val.(SecurityVendorInformationable))
        }
        return nil
    }
    res["vulnerabilityStates"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetCollectionOfObjectValues(CreateVulnerabilityStateFromDiscriminatorValue)
        if err != nil {
            return err
        }
        if val != nil {
            res := make([]VulnerabilityStateable, len(val))
            for i, v := range val {
                res[i] = v.(VulnerabilityStateable)
            }
            m.SetVulnerabilityStates(res)
        }
        return nil
    }
    return res
}
// GetFileStates gets the fileStates property value. Security-related stateful information generated by the provider about the file(s) related to this alert.
func (m *Alert) GetFileStates()([]FileSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.fileStates
    }
}
// GetHistoryStates gets the historyStates property value. A collection of alertHistoryStates comprising an audit log of all updates made to an alert.
func (m *Alert) GetHistoryStates()([]AlertHistoryStateable) {
    if m == nil {
        return nil
    } else {
        return m.historyStates
    }
}
// GetHostStates gets the hostStates property value. Security-related stateful information generated by the provider about the host(s) related to this alert.
func (m *Alert) GetHostStates()([]HostSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.hostStates
    }
}
// GetIncidentIds gets the incidentIds property value. IDs of incidents related to current alert.
func (m *Alert) GetIncidentIds()([]string) {
    if m == nil {
        return nil
    } else {
        return m.incidentIds
    }
}
// GetInvestigationSecurityStates gets the investigationSecurityStates property value. The investigationSecurityStates property
func (m *Alert) GetInvestigationSecurityStates()([]InvestigationSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.investigationSecurityStates
    }
}
// GetLastEventDateTime gets the lastEventDateTime property value. The lastEventDateTime property
func (m *Alert) GetLastEventDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    if m == nil {
        return nil
    } else {
        return m.lastEventDateTime
    }
}
// GetLastModifiedDateTime gets the lastModifiedDateTime property value. Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
func (m *Alert) GetLastModifiedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    if m == nil {
        return nil
    } else {
        return m.lastModifiedDateTime
    }
}
// GetMalwareStates gets the malwareStates property value. Threat Intelligence pertaining to malware related to this alert.
func (m *Alert) GetMalwareStates()([]MalwareStateable) {
    if m == nil {
        return nil
    } else {
        return m.malwareStates
    }
}
// GetMessageSecurityStates gets the messageSecurityStates property value. The messageSecurityStates property
func (m *Alert) GetMessageSecurityStates()([]MessageSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.messageSecurityStates
    }
}
// GetNetworkConnections gets the networkConnections property value. Security-related stateful information generated by the provider about the network connection(s) related to this alert.
func (m *Alert) GetNetworkConnections()([]NetworkConnectionable) {
    if m == nil {
        return nil
    } else {
        return m.networkConnections
    }
}
// GetProcesses gets the processes property value. Security-related stateful information generated by the provider about the process or processes related to this alert.
func (m *Alert) GetProcesses()([]Processable) {
    if m == nil {
        return nil
    } else {
        return m.processes
    }
}
// GetRecommendedActions gets the recommendedActions property value. Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).
func (m *Alert) GetRecommendedActions()([]string) {
    if m == nil {
        return nil
    } else {
        return m.recommendedActions
    }
}
// GetRegistryKeyStates gets the registryKeyStates property value. Security-related stateful information generated by the provider about the registry keys related to this alert.
func (m *Alert) GetRegistryKeyStates()([]RegistryKeyStateable) {
    if m == nil {
        return nil
    } else {
        return m.registryKeyStates
    }
}
// GetSecurityResources gets the securityResources property value. Resources related to current alert. For example, for some alerts this can have the Azure Resource value.
func (m *Alert) GetSecurityResources()([]SecurityResourceable) {
    if m == nil {
        return nil
    } else {
        return m.securityResources
    }
}
// GetSeverity gets the severity property value. The severity property
func (m *Alert) GetSeverity()(*AlertSeverity) {
    if m == nil {
        return nil
    } else {
        return m.severity
    }
}
// GetSourceMaterials gets the sourceMaterials property value. Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.
func (m *Alert) GetSourceMaterials()([]string) {
    if m == nil {
        return nil
    } else {
        return m.sourceMaterials
    }
}
// GetStatus gets the status property value. The status property
func (m *Alert) GetStatus()(*AlertStatus) {
    if m == nil {
        return nil
    } else {
        return m.status
    }
}
// GetTags gets the tags property value. User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).
func (m *Alert) GetTags()([]string) {
    if m == nil {
        return nil
    } else {
        return m.tags
    }
}
// GetTitle gets the title property value. Alert title. Required.
func (m *Alert) GetTitle()(*string) {
    if m == nil {
        return nil
    } else {
        return m.title
    }
}
// GetTriggers gets the triggers property value. Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.
func (m *Alert) GetTriggers()([]AlertTriggerable) {
    if m == nil {
        return nil
    } else {
        return m.triggers
    }
}
// GetUriClickSecurityStates gets the uriClickSecurityStates property value. The uriClickSecurityStates property
func (m *Alert) GetUriClickSecurityStates()([]UriClickSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.uriClickSecurityStates
    }
}
// GetUserStates gets the userStates property value. Security-related stateful information generated by the provider about the user accounts related to this alert.
func (m *Alert) GetUserStates()([]UserSecurityStateable) {
    if m == nil {
        return nil
    } else {
        return m.userStates
    }
}
// GetVendorInformation gets the vendorInformation property value. Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.
func (m *Alert) GetVendorInformation()(SecurityVendorInformationable) {
    if m == nil {
        return nil
    } else {
        return m.vendorInformation
    }
}
// GetVulnerabilityStates gets the vulnerabilityStates property value. Threat intelligence pertaining to one or more vulnerabilities related to this alert.
func (m *Alert) GetVulnerabilityStates()([]VulnerabilityStateable) {
    if m == nil {
        return nil
    } else {
        return m.vulnerabilityStates
    }
}
// Serialize serializes information the current object
func (m *Alert) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter)(error) {
    err := m.Entity.Serialize(writer)
    if err != nil {
        return err
    }
    {
        err = writer.WriteStringValue("activityGroupName", m.GetActivityGroupName())
        if err != nil {
            return err
        }
    }
    if m.GetAlertDetections() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetAlertDetections()))
        for i, v := range m.GetAlertDetections() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("alertDetections", cast)
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteStringValue("assignedTo", m.GetAssignedTo())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteStringValue("azureSubscriptionId", m.GetAzureSubscriptionId())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteStringValue("azureTenantId", m.GetAzureTenantId())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteStringValue("category", m.GetCategory())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteTimeValue("closedDateTime", m.GetClosedDateTime())
        if err != nil {
            return err
        }
    }
    if m.GetCloudAppStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetCloudAppStates()))
        for i, v := range m.GetCloudAppStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("cloudAppStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetComments() != nil {
        err = writer.WriteCollectionOfStringValues("comments", m.GetComments())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteInt32Value("confidence", m.GetConfidence())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteTimeValue("createdDateTime", m.GetCreatedDateTime())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteStringValue("description", m.GetDescription())
        if err != nil {
            return err
        }
    }
    if m.GetDetectionIds() != nil {
        err = writer.WriteCollectionOfStringValues("detectionIds", m.GetDetectionIds())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteTimeValue("eventDateTime", m.GetEventDateTime())
        if err != nil {
            return err
        }
    }
    if m.GetFeedback() != nil {
        cast := (*m.GetFeedback()).String()
        err = writer.WriteStringValue("feedback", &cast)
        if err != nil {
            return err
        }
    }
    if m.GetFileStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetFileStates()))
        for i, v := range m.GetFileStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("fileStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetHistoryStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetHistoryStates()))
        for i, v := range m.GetHistoryStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("historyStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetHostStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetHostStates()))
        for i, v := range m.GetHostStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("hostStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetIncidentIds() != nil {
        err = writer.WriteCollectionOfStringValues("incidentIds", m.GetIncidentIds())
        if err != nil {
            return err
        }
    }
    if m.GetInvestigationSecurityStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetInvestigationSecurityStates()))
        for i, v := range m.GetInvestigationSecurityStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("investigationSecurityStates", cast)
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteTimeValue("lastEventDateTime", m.GetLastEventDateTime())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteTimeValue("lastModifiedDateTime", m.GetLastModifiedDateTime())
        if err != nil {
            return err
        }
    }
    if m.GetMalwareStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetMalwareStates()))
        for i, v := range m.GetMalwareStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("malwareStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetMessageSecurityStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetMessageSecurityStates()))
        for i, v := range m.GetMessageSecurityStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("messageSecurityStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetNetworkConnections() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetNetworkConnections()))
        for i, v := range m.GetNetworkConnections() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("networkConnections", cast)
        if err != nil {
            return err
        }
    }
    if m.GetProcesses() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetProcesses()))
        for i, v := range m.GetProcesses() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("processes", cast)
        if err != nil {
            return err
        }
    }
    if m.GetRecommendedActions() != nil {
        err = writer.WriteCollectionOfStringValues("recommendedActions", m.GetRecommendedActions())
        if err != nil {
            return err
        }
    }
    if m.GetRegistryKeyStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetRegistryKeyStates()))
        for i, v := range m.GetRegistryKeyStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("registryKeyStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetSecurityResources() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetSecurityResources()))
        for i, v := range m.GetSecurityResources() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("securityResources", cast)
        if err != nil {
            return err
        }
    }
    if m.GetSeverity() != nil {
        cast := (*m.GetSeverity()).String()
        err = writer.WriteStringValue("severity", &cast)
        if err != nil {
            return err
        }
    }
    if m.GetSourceMaterials() != nil {
        err = writer.WriteCollectionOfStringValues("sourceMaterials", m.GetSourceMaterials())
        if err != nil {
            return err
        }
    }
    if m.GetStatus() != nil {
        cast := (*m.GetStatus()).String()
        err = writer.WriteStringValue("status", &cast)
        if err != nil {
            return err
        }
    }
    if m.GetTags() != nil {
        err = writer.WriteCollectionOfStringValues("tags", m.GetTags())
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteStringValue("title", m.GetTitle())
        if err != nil {
            return err
        }
    }
    if m.GetTriggers() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetTriggers()))
        for i, v := range m.GetTriggers() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("triggers", cast)
        if err != nil {
            return err
        }
    }
    if m.GetUriClickSecurityStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetUriClickSecurityStates()))
        for i, v := range m.GetUriClickSecurityStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("uriClickSecurityStates", cast)
        if err != nil {
            return err
        }
    }
    if m.GetUserStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetUserStates()))
        for i, v := range m.GetUserStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("userStates", cast)
        if err != nil {
            return err
        }
    }
    {
        err = writer.WriteObjectValue("vendorInformation", m.GetVendorInformation())
        if err != nil {
            return err
        }
    }
    if m.GetVulnerabilityStates() != nil {
        cast := make([]i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, len(m.GetVulnerabilityStates()))
        for i, v := range m.GetVulnerabilityStates() {
            cast[i] = v.(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable)
        }
        err = writer.WriteCollectionOfObjectValues("vulnerabilityStates", cast)
        if err != nil {
            return err
        }
    }
    return nil
}
// SetActivityGroupName sets the activityGroupName property value. Name or alias of the activity group (attacker) this alert is attributed to.
func (m *Alert) SetActivityGroupName(value *string)() {
    if m != nil {
        m.activityGroupName = value
    }
}
// SetAlertDetections sets the alertDetections property value. The alertDetections property
func (m *Alert) SetAlertDetections(value []AlertDetectionable)() {
    if m != nil {
        m.alertDetections = value
    }
}
// SetAssignedTo sets the assignedTo property value. Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).
func (m *Alert) SetAssignedTo(value *string)() {
    if m != nil {
        m.assignedTo = value
    }
}
// SetAzureSubscriptionId sets the azureSubscriptionId property value. Azure subscription ID, present if this alert is related to an Azure resource.
func (m *Alert) SetAzureSubscriptionId(value *string)() {
    if m != nil {
        m.azureSubscriptionId = value
    }
}
// SetAzureTenantId sets the azureTenantId property value. Azure Active Directory tenant ID. Required.
func (m *Alert) SetAzureTenantId(value *string)() {
    if m != nil {
        m.azureTenantId = value
    }
}
// SetCategory sets the category property value. Category of the alert (for example, credentialTheft, ransomware, etc.).
func (m *Alert) SetCategory(value *string)() {
    if m != nil {
        m.category = value
    }
}
// SetClosedDateTime sets the closedDateTime property value. Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).
func (m *Alert) SetClosedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    if m != nil {
        m.closedDateTime = value
    }
}
// SetCloudAppStates sets the cloudAppStates property value. Security-related stateful information generated by the provider about the cloud application/s related to this alert.
func (m *Alert) SetCloudAppStates(value []CloudAppSecurityStateable)() {
    if m != nil {
        m.cloudAppStates = value
    }
}
// SetComments sets the comments property value. Customer-provided comments on alert (for customer alert management) (supports update).
func (m *Alert) SetComments(value []string)() {
    if m != nil {
        m.comments = value
    }
}
// SetConfidence sets the confidence property value. Confidence of the detection logic (percentage between 1-100).
func (m *Alert) SetConfidence(value *int32)() {
    if m != nil {
        m.confidence = value
    }
}
// SetCreatedDateTime sets the createdDateTime property value. Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
func (m *Alert) SetCreatedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    if m != nil {
        m.createdDateTime = value
    }
}
// SetDescription sets the description property value. Alert description.
func (m *Alert) SetDescription(value *string)() {
    if m != nil {
        m.description = value
    }
}
// SetDetectionIds sets the detectionIds property value. Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).
func (m *Alert) SetDetectionIds(value []string)() {
    if m != nil {
        m.detectionIds = value
    }
}
// SetEventDateTime sets the eventDateTime property value. Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
func (m *Alert) SetEventDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    if m != nil {
        m.eventDateTime = value
    }
}
// SetFeedback sets the feedback property value. Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)
func (m *Alert) SetFeedback(value *AlertFeedback)() {
    if m != nil {
        m.feedback = value
    }
}
// SetFileStates sets the fileStates property value. Security-related stateful information generated by the provider about the file(s) related to this alert.
func (m *Alert) SetFileStates(value []FileSecurityStateable)() {
    if m != nil {
        m.fileStates = value
    }
}
// SetHistoryStates sets the historyStates property value. A collection of alertHistoryStates comprising an audit log of all updates made to an alert.
func (m *Alert) SetHistoryStates(value []AlertHistoryStateable)() {
    if m != nil {
        m.historyStates = value
    }
}
// SetHostStates sets the hostStates property value. Security-related stateful information generated by the provider about the host(s) related to this alert.
func (m *Alert) SetHostStates(value []HostSecurityStateable)() {
    if m != nil {
        m.hostStates = value
    }
}
// SetIncidentIds sets the incidentIds property value. IDs of incidents related to current alert.
func (m *Alert) SetIncidentIds(value []string)() {
    if m != nil {
        m.incidentIds = value
    }
}
// SetInvestigationSecurityStates sets the investigationSecurityStates property value. The investigationSecurityStates property
func (m *Alert) SetInvestigationSecurityStates(value []InvestigationSecurityStateable)() {
    if m != nil {
        m.investigationSecurityStates = value
    }
}
// SetLastEventDateTime sets the lastEventDateTime property value. The lastEventDateTime property
func (m *Alert) SetLastEventDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    if m != nil {
        m.lastEventDateTime = value
    }
}
// SetLastModifiedDateTime sets the lastModifiedDateTime property value. Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
func (m *Alert) SetLastModifiedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    if m != nil {
        m.lastModifiedDateTime = value
    }
}
// SetMalwareStates sets the malwareStates property value. Threat Intelligence pertaining to malware related to this alert.
func (m *Alert) SetMalwareStates(value []MalwareStateable)() {
    if m != nil {
        m.malwareStates = value
    }
}
// SetMessageSecurityStates sets the messageSecurityStates property value. The messageSecurityStates property
func (m *Alert) SetMessageSecurityStates(value []MessageSecurityStateable)() {
    if m != nil {
        m.messageSecurityStates = value
    }
}
// SetNetworkConnections sets the networkConnections property value. Security-related stateful information generated by the provider about the network connection(s) related to this alert.
func (m *Alert) SetNetworkConnections(value []NetworkConnectionable)() {
    if m != nil {
        m.networkConnections = value
    }
}
// SetProcesses sets the processes property value. Security-related stateful information generated by the provider about the process or processes related to this alert.
func (m *Alert) SetProcesses(value []Processable)() {
    if m != nil {
        m.processes = value
    }
}
// SetRecommendedActions sets the recommendedActions property value. Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).
func (m *Alert) SetRecommendedActions(value []string)() {
    if m != nil {
        m.recommendedActions = value
    }
}
// SetRegistryKeyStates sets the registryKeyStates property value. Security-related stateful information generated by the provider about the registry keys related to this alert.
func (m *Alert) SetRegistryKeyStates(value []RegistryKeyStateable)() {
    if m != nil {
        m.registryKeyStates = value
    }
}
// SetSecurityResources sets the securityResources property value. Resources related to current alert. For example, for some alerts this can have the Azure Resource value.
func (m *Alert) SetSecurityResources(value []SecurityResourceable)() {
    if m != nil {
        m.securityResources = value
    }
}
// SetSeverity sets the severity property value. The severity property
func (m *Alert) SetSeverity(value *AlertSeverity)() {
    if m != nil {
        m.severity = value
    }
}
// SetSourceMaterials sets the sourceMaterials property value. Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.
func (m *Alert) SetSourceMaterials(value []string)() {
    if m != nil {
        m.sourceMaterials = value
    }
}
// SetStatus sets the status property value. The status property
func (m *Alert) SetStatus(value *AlertStatus)() {
    if m != nil {
        m.status = value
    }
}
// SetTags sets the tags property value. User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).
func (m *Alert) SetTags(value []string)() {
    if m != nil {
        m.tags = value
    }
}
// SetTitle sets the title property value. Alert title. Required.
func (m *Alert) SetTitle(value *string)() {
    if m != nil {
        m.title = value
    }
}
// SetTriggers sets the triggers property value. Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.
func (m *Alert) SetTriggers(value []AlertTriggerable)() {
    if m != nil {
        m.triggers = value
    }
}
// SetUriClickSecurityStates sets the uriClickSecurityStates property value. The uriClickSecurityStates property
func (m *Alert) SetUriClickSecurityStates(value []UriClickSecurityStateable)() {
    if m != nil {
        m.uriClickSecurityStates = value
    }
}
// SetUserStates sets the userStates property value. Security-related stateful information generated by the provider about the user accounts related to this alert.
func (m *Alert) SetUserStates(value []UserSecurityStateable)() {
    if m != nil {
        m.userStates = value
    }
}
// SetVendorInformation sets the vendorInformation property value. Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.
func (m *Alert) SetVendorInformation(value SecurityVendorInformationable)() {
    if m != nil {
        m.vendorInformation = value
    }
}
// SetVulnerabilityStates sets the vulnerabilityStates property value. Threat intelligence pertaining to one or more vulnerabilities related to this alert.
func (m *Alert) SetVulnerabilityStates(value []VulnerabilityStateable)() {
    if m != nil {
        m.vulnerabilityStates = value
    }
}
